@@ -1,7 +1,7 @@
 import turtle as tu
 import cv2
 from svgpathtools import svg2paths2
-from svg.path import Path , parse_path
+from svg.path import parse_path
 
 
 
